Tutorial 6: GPU Acceleration
=============================

.. deprecated::
   This tutorial has been superseded by the structured tutorial guide.

See :doc:`/tutorials/routine/gpu_acceleration/gpu_usage` for the updated version.
